@@ -1,20 +1,8 @@
 /*
-   Copyright 2009 David Nolden <david.nolden.kdevelop@art-master.de>
+    SPDX-FileCopyrightText: 2009 David Nolden <david.nolden.kdevelop@art-master.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "parseprojectjob.h"
 
@@ -31,7 +19,7 @@
 #include <kcoreaddons_version.h>
 #include <KLocalizedString>
 
-#include <QApplication>
+#include <QCoreApplication>
 #include <QPointer>
 #include <QSet>
 #include <QTimer>
@@ -72,9 +60,10 @@ ParseProjectJob::ParseProjectJob(IProject* project, bool forceUpdate, bool parse
     } else {
         // In case we don't want to parse the whole project, still add all currently open files that belong to the project to the background-parser
         const auto documents = ICore::self()->documentController()->openDocuments();
+        const auto projectFiles = project->fileSet();
         for (auto* document : documents) {
             const auto path = IndexedString(document->url());
-            if (project->fileSet().contains(path)) {
+            if (projectFiles.contains(path)) {
                 d->filesToParse.insert(path);
             }
         }
@@ -109,7 +98,7 @@ void ParseProjectJob::start()
     }
 
     qCDebug(LANGUAGE) << "starting project parse job";
-    // Avoid calling QApplication::processEvents() directly in start() to prevent
+    // Avoid calling QCoreApplication::processEvents() directly in start() to prevent
     // a crash in RunController::checkState().
     QTimer::singleShot(0, this, &ParseProjectJob::queueFilesToParse);
 }
@@ -146,8 +135,8 @@ void ParseProjectJob::queueFilesToParse()
         if (processingLevel & TopDUContext::VisibleDeclarationsAndContexts) {
             processingLevel = TopDUContext::AllDeclarationsContextsAndUses;
         }
-        processingLevel = ( TopDUContext::Features )(TopDUContext::ForceUpdate | processingLevel);
-        openDocumentProcessingLevel = TopDUContext::Features(TopDUContext::ForceUpdate | openDocumentProcessingLevel);
+        processingLevel |= TopDUContext::ForceUpdate;
+        openDocumentProcessingLevel |= TopDUContext::ForceUpdate;
     }
 
     if (auto currentDocument = ICore::self()->documentController()->activeDocument()) {
@@ -193,7 +182,7 @@ void ParseProjectJob::queueFilesToParse()
                                                                              this);
         ++processed;
         if (processed == processAfter) {
-            QApplication::processEvents();
+            QCoreApplication::processEvents();
             if (Q_UNLIKELY(!crashGuard)) {
                 qCDebug(LANGUAGE) << "Aborting queuing project files to parse."
                                      " This job has been destroyed.";
@@ -205,4 +194,6 @@ void ParseProjectJob::queueFilesToParse()
             processed = 0;
         }
     }
+
+    d->filesToParse = {}; // free memory or prevent detaching
 }
