@@ -1,16 +1,13 @@
-/***************************************************************************
- *   Copyright 2001 Bernd Gehrmann <bernd@kdevelop.org>                    *
- *   Copyright 2004-2005 Sascha Cunz <sascha@kdevelop.org>                 *
- *   Copyright 2005 Ian Reinhart Geiser <ian@geiseri.com>                  *
- *   Copyright 2007 Alexander Dymo <adymo@kdevelop.org>                    *
- *   Copyright 2008 Evgeniy Ivanov <powerfox@kde.ru>                       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2001 Bernd Gehrmann <bernd@kdevelop.org>
+    SPDX-FileCopyrightText: 2004-2005 Sascha Cunz <sascha@kdevelop.org>
+    SPDX-FileCopyrightText: 2005 Ian Reinhart Geiser <ian@geiseri.com>
+    SPDX-FileCopyrightText: 2007 Alexander Dymo <adymo@kdevelop.org>
+    SPDX-FileCopyrightText: 2008 Evgeniy Ivanov <powerfox@kde.ru>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
+
 #include "appwizardplugin.h"
 
 #include <QAction>
@@ -160,12 +157,27 @@ bool initializeDVCS(IDistributedVersionControl* dvcs, const ApplicationInfo& inf
     }
     qCDebug(PLUGIN_APPWIZARD) << "Initializing DVCS repository:" << dest;
 
+    qCDebug(PLUGIN_APPWIZARD) << "Checking for valid files in the DVCS repository:" << dest;
+    job = dvcs->status({dest}, KDevelop::IBasicVersionControl::Recursive);
+    if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded)
+    {
+        vcsError(i18n("Could not check status of the DVCS repository"), scratchArea, dest);
+        return false;
+    }
+
+    if (job->fetchResults().toList().isEmpty())
+    {
+        qCDebug(PLUGIN_APPWIZARD) << "No files to add, skipping commit in the DVCS repository:" << dest;
+        return true;
+    }
+
     job = dvcs->add({dest}, KDevelop::IBasicVersionControl::Recursive);
     if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded)
     {
         vcsError(i18n("Could not add files to the DVCS repository"), scratchArea, dest);
         return false;
     }
+
     job = dvcs->commit(info.importCommitMessage, {dest},
                             KDevelop::IBasicVersionControl::Recursive);
     if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded)
@@ -244,7 +256,7 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
     //prepare variable substitution hash
     m_variables.clear();
     m_variables[QStringLiteral("APPNAME")] = info.name;
-    m_variables[QStringLiteral("APPNAMEUC")] = info.name.toUpper();
+    m_variables[QStringLiteral("APPNAMEUC")] = generateIdentifier(info.name.toUpper());
     m_variables[QStringLiteral("APPNAMELC")] = info.name.toLower();
     m_variables[QStringLiteral("APPNAMEID")] = generateIdentifier(info.name);
     m_variables[QStringLiteral("PROJECTDIR")] = dest.toLocalFile();
